---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/facebook/ktfmt",
    description = "Reformats Kotlin source code to comply with the common community standard conventions.",
  },
  command = "ktfmt",
  args = { "-" },
}
