---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/google/keep-sorted",
    description = "keep-sorted is a language-agnostic formatter that sorts lines between two markers in a larger file.",
  },

  command = "keep-sorted",
  args = { "-" },
}
