---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/Enter-tainer/typstyle",
    description = "Beautiful and reliable typst code formatter.",
  },
  command = "typstyle",
  stdin = true,
}
