---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/avencera/rustywind",
    description = "A tool for formatting Tailwind CSS classes.",
  },
  command = "rustywind",
  args = { "--stdin" },
}
