---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/Scony/godot-gdscript-toolkit",
    description = "A formatter for Godot's gdscript.",
  },
  command = "gdformat",
  args = { "-" },
}
