---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/ducminh-phan/reformat-gherkin",
    description = "Formatter for Gherkin language.",
  },
  command = "reformat-gherkin",
  args = { "-" },
  stdin = true,
}
