---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/nrempel/sleek",
    description = "Sleek is a CLI tool for formatting SQL.",
  },
  command = "sleek",
  stdin = true,
}
