---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/cheshirekow/cmake_format",
    description = "Parse cmake listfiles and format them nicely.",
  },
  command = "cmake-format",
  args = { "-" },
}
