---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/nebulab/erb-formatter",
    description = "Format ERB files with speed and precision.",
  },
  command = "erb-format",
  args = { "--stdin" },
}
