---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/razziel89/mdslw",
    description = "Prepare your markdown for easy diff'ing by adding line breaks after every sentence.",
  },
  command = "mdslw",
}
