---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/WGUNDERWOOD/tex-fmt",
    description = "An extremely fast LaTeX formatter written in Rust.",
  },
  command = "tex-fmt",
  args = { "-s" },
}
