---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://inko-lang.org/",
    description = "A language for building concurrent software with confidence",
  },
  command = "inko",
  args = { "fmt", "-" },
}
