---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/astrale-sharp/typstfmt",
    description = "Basic formatter for the Typst language with a future!",
    deprecated = true,
  },
  command = "typstfmt",
  stdin = true,
}
