---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/pamoller/xmlformatter",
    description = "xmlformatter is an Open Source Python package, which provides formatting of XML documents.",
  },
  command = "xmlformat",
  args = { "-" },
}
