---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/vinta/pangu.py",
    description = "Insert whitespace between CJK and half-width characters.",
  },
  command = "pangu",
  stdin = true,
}
