---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/slomkowski/nginx-config-formatter",
    description = "nginx config file formatter/beautifier written in Python with no additional dependencies.",
  },
  command = "nginxfmt",
  args = { "-" },
}
