---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/perltidy/perltidy",
    description = "Perl::Tidy, a source code formatter for Perl.",
  },
  command = "perltidy",
  args = { "--quiet" },
}
