---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/terrastruct/d2",
    description = "D2 is a modern diagram scripting language that turns text to diagrams.",
  },
  command = "d2",
  args = { "fmt", "-" },
}
