---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/bram209/leptosfmt",
    description = "A formatter for the Leptos view! macro.",
  },
  command = "leptosfmt",
  args = { "--stdin" },
}
