---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/tamasfe/taplo",
    description = "A TOML toolkit written in Rust.",
  },
  command = "taplo",
  args = { "format", "-" },
}
