---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/lyz-code/yamlfix",
    description = "A configurable YAML formatter that keeps comments.",
  },
  command = "yamlfix",
  args = { "-" },
}
