---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/anordal/shellharden",
    description = "The corrective bash syntax highlighter.",
  },
  command = "shellharden",
  args = { "--transform", "" },
}
