---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/google/yamlfmt",
    description = "yamlfmt is an extensible command line tool or library to format yaml files.",
  },
  command = "yamlfmt",
  args = { "-" },
}
