---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/threedaymonk/htmlbeautifier",
    description = "A normaliser/beautifier for HTML that also understands embedded Ruby. Ideal for tidying up Rails templates.",
  },
  command = "htmlbeautifier",
}
