---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/shwestrick/smlfmt",
    description = "A custom parser and code formatter for Standard ML.",
  },
  command = "smlfmt",
}
