---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/wvermin/findent",
    description = "Indent, relabel and convert Fortran sources.",
  },
  command = "findent",
  stdin = true,
}
