---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://templ.guide/developer-tools/cli/#formatting-templ-files",
    description = "Formats templ template files.",
  },
  command = "templ",
  args = { "fmt" },
}
