---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/OCamlPro/ocp-indent",
    description = "Automatic indentation of OCaml source files.",
  },
  command = "ocp-indent",
}
