---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/NixOS/nixfmt",
    description = "The official (but not yet stable) formatter for Nix code.",
  },
  command = "nixfmt",
}
