---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://fishshell.com/docs/current/cmds/fish_indent.html",
    description = "Indent or otherwise prettify a piece of fish code.",
  },
  command = "fish_indent",
}
