---@type conform.FileFormatterConfig
return {
  meta = {
    url = "https://github.com/executablebooks/mdformat",
    description = "An opinionated Markdown formatter.",
  },
  command = "mdformat",
  args = { "-" },
}
